@@ -33,11 +33,11 @@ class AllOfKeyword(Keyword, ArrayApplicator):
         for index, subschema in enumerate(self.json):
             with scope(instance, str(index)) as subscope:
                 subschema.evaluate(instance, subscope)
-                if not subscope.valid:
+                if not subscope.passed:
                     err_indices += [index]
 
         if err_indices:
-            scope.fail(instance, f'The instance is invalid against subschemas {err_indices}')
+            scope.fail(f'The instance is invalid against subschemas {err_indices}')
 
 
 class AnyOfKeyword(Keyword, ArrayApplicator):
@@ -48,11 +48,11 @@ class AnyOfKeyword(Keyword, ArrayApplicator):
         for index, subschema in enumerate(self.json):
             with scope(instance, str(index)) as subscope:
                 subschema.evaluate(instance, subscope)
-                if subscope.valid:
+                if subscope.passed:
                     valid = True
 
         if not valid:
-            scope.fail(instance, f'The instance must be valid against at least one subschema')
+            scope.fail(f'The instance must be valid against at least one subschema')
 
 
 class OneOfKeyword(Keyword, ArrayApplicator):
@@ -64,14 +64,14 @@ class OneOfKeyword(Keyword, ArrayApplicator):
         for index, subschema in enumerate(self.json):
             with scope(instance, str(index)) as subscope:
                 subschema.evaluate(instance, subscope)
-                if subscope.valid:
+                if subscope.passed:
                     valid_indices += [index]
                 else:
                     err_indices += [index]
 
         if len(valid_indices) != 1:
-            scope.fail(instance, 'The instance must be valid against exactly one subschema; '
-                                 f'it is valid against {valid_indices} and invalid against {err_indices}')
+            scope.fail('The instance must be valid against exactly one subschema; '
+                       f'it is valid against {valid_indices} and invalid against {err_indices}')
 
 
 class NotKeyword(Keyword, Applicator):
@@ -80,10 +80,10 @@ class NotKeyword(Keyword, Applicator):
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         self.json.evaluate(instance, scope)
 
-        if scope.valid:
-            scope.fail(instance, 'The instance must not be valid against the subschema')
+        if scope.passed:
+            scope.fail('The instance must not be valid against the subschema')
         else:
-            scope.errors.clear()
+            scope.pass_()
 
 
 class IfKeyword(Keyword, Applicator):
@@ -99,7 +99,7 @@ class ThenKeyword(Keyword, Applicator):
     depends = "if"
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
-        if (if_ := scope.sibling(instance, "if")) and not if_.errors:
+        if (if_ := scope.sibling(instance, "if")) and if_.valid:
             self.json.evaluate(instance, scope)
         else:
             scope.discard()
@@ -110,7 +110,7 @@ class ElseKeyword(Keyword, Applicator):
     depends = "if"
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
-        if (if_ := scope.sibling(instance, "if")) and if_.errors:
+        if (if_ := scope.sibling(instance, "if")) and not if_.valid:
             self.json.evaluate(instance, scope)
         else:
             scope.discard()
@@ -127,16 +127,16 @@ class DependentSchemasKeyword(Keyword, PropertyApplicator):
             if name in instance:
                 with scope(instance, name) as subscope:
                     subschema.evaluate(instance, subscope)
-                    if subscope.valid:
+                    if subscope.passed:
                         annotation += [name]
                     else:
                         err_names += [name]
 
         if err_names:
-            scope.fail(instance, f'Properties {err_names} are invalid against '
-                                 f'the corresponding "dependentSchemas" subschemas')
+            scope.fail(f'Properties {err_names} are invalid against '
+                       f'the corresponding "dependentSchemas" subschemas')
         else:
-            scope.annotate(instance, self.key, annotation)
+            scope.annotate(annotation)
 
 
 class PrefixItemsKeyword(Keyword, ArrayApplicator):
@@ -150,15 +150,15 @@ class PrefixItemsKeyword(Keyword, ArrayApplicator):
             eval_index = index
             with scope(item, str(index)) as subscope:
                 self.json[index].evaluate(item, subscope)
-                if not subscope.valid:
+                if not subscope.passed:
                     err_indices += [index]
 
         if err_indices:
-            scope.fail(instance, f"Array elements {err_indices} are invalid")
+            scope.fail(f"Array elements {err_indices} are invalid")
         elif eval_index is not None:
             if eval_index == len(instance) - 1:
                 eval_index = True
-            scope.annotate(instance, self.key, eval_index)
+            scope.annotate(eval_index)
 
 
 class ItemsKeyword(Keyword, Applicator):
@@ -168,11 +168,11 @@ class ItemsKeyword(Keyword, Applicator):
 
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         if (prefix_items := scope.sibling(instance, "prefixItems")) and \
-                (prefix_items_annotation := prefix_items.annotations.get("prefixItems")):
-            if prefix_items_annotation.value is True:
+                prefix_items.annotation is not None:
+            if prefix_items.annotation is True:
                 return
             else:
-                start_index = prefix_items_annotation.value + 1
+                start_index = prefix_items.annotation + 1
         else:
             start_index = 0
 
@@ -181,8 +181,8 @@ class ItemsKeyword(Keyword, Applicator):
             annotation = True
             self.json.evaluate(item, scope)
 
-        if annotation is True and scope.valid:
-            scope.annotate(instance, self.key, annotation)
+        if annotation is True and scope.passed:
+            scope.annotate(annotation)
 
 
 class UnevaluatedItemsKeyword(Keyword, Applicator):
@@ -193,25 +193,25 @@ class UnevaluatedItemsKeyword(Keyword, Applicator):
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         last_evaluated_item = -1
         for prefix_items_annotation in scope.parent.collect_annotations(instance, "prefixItems"):
-            if prefix_items_annotation.value is True:
+            if prefix_items_annotation is True:
                 scope.discard()
                 return
-            if prefix_items_annotation.value > last_evaluated_item:
-                last_evaluated_item = prefix_items_annotation.value
+            if prefix_items_annotation > last_evaluated_item:
+                last_evaluated_item = prefix_items_annotation
 
         for items_annotation in scope.parent.collect_annotations(instance, "items"):
-            if items_annotation.value is True:
+            if items_annotation is True:
                 scope.discard()
                 return
 
         for unevaluated_items_annotation in scope.parent.collect_annotations(instance, "unevaluatedItems"):
-            if unevaluated_items_annotation.value is True:
+            if unevaluated_items_annotation is True:
                 scope.discard()
                 return
 
         contains_indices = set()
         for contains_annotation in scope.parent.collect_annotations(instance, "contains"):
-            contains_indices |= set(contains_annotation.value)
+            contains_indices |= set(contains_annotation)
 
         annotation = None
         for index, item in enumerate(instance[(start := last_evaluated_item + 1):], start):
@@ -219,8 +219,8 @@ class UnevaluatedItemsKeyword(Keyword, Applicator):
                 annotation = True
                 self.json.evaluate(item, scope)
 
-        if scope.valid:
-            scope.annotate(instance, self.key, annotation)
+        if scope.passed:
+            scope.annotate(annotation)
 
 
 class ContainsKeyword(Keyword, Applicator):
@@ -230,15 +230,15 @@ class ContainsKeyword(Keyword, Applicator):
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         annotation = []
         for index, item in enumerate(instance):
-            if self.json.evaluate(item, scope).valid:
+            if self.json.evaluate(item, scope).passed:
                 annotation += [index]
             else:
-                scope.errors.clear()
+                scope.pass_()
 
-        scope.annotate(instance, self.key, annotation)
+        scope.annotate(annotation)
         if not annotation:
-            scope.fail(instance, 'The array does not contain any element that is valid '
-                                 f'against the "{self.key}" subschema')
+            scope.fail('The array does not contain any element that is valid '
+                       f'against the "{self.key}" subschema')
 
 
 class PropertiesKeyword(Keyword, PropertyApplicator):
@@ -252,15 +252,15 @@ class PropertiesKeyword(Keyword, PropertyApplicator):
             if name in self.json:
                 with scope(item, name) as subscope:
                     self.json[name].evaluate(item, subscope)
-                    if subscope.valid:
+                    if subscope.passed:
                         annotation += [name]
                     else:
                         err_names += [name]
 
         if err_names:
-            scope.fail(instance, f"Properties {err_names} are invalid")
+            scope.fail(f"Properties {err_names} are invalid")
         else:
-            scope.annotate(instance, self.key, annotation)
+            scope.annotate(annotation)
 
 
 class PatternPropertiesKeyword(Keyword, PropertyApplicator):
@@ -275,15 +275,15 @@ class PatternPropertiesKeyword(Keyword, PropertyApplicator):
                 if re.search(regex, name) is not None:
                     with scope(item, regex) as subscope:
                         subschema.evaluate(item, subscope)
-                        if subscope.valid:
+                        if subscope.passed:
                             matched_names |= {name}
                         else:
                             err_names += [name]
 
         if err_names:
-            scope.fail(instance, f"Properties {err_names} are invalid")
+            scope.fail(f"Properties {err_names} are invalid")
         else:
-            scope.annotate(instance, self.key, list(matched_names))
+            scope.annotate(list(matched_names))
 
 
 class AdditionalPropertiesKeyword(Keyword, Applicator):
@@ -294,21 +294,21 @@ class AdditionalPropertiesKeyword(Keyword, Applicator):
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         evaluated_names = set()
         if (properties := scope.sibling(instance, "properties")) and \
-                (properties_annotation := properties.annotations.get("properties")):
-            evaluated_names |= set(properties_annotation.value)
+                properties.annotation is not None:
+            evaluated_names |= set(properties.annotation)
 
         if (pattern_properties := scope.sibling(instance, "patternProperties")) and \
-                (pattern_properties_annotation := pattern_properties.annotations.get("patternProperties")):
-            evaluated_names |= set(pattern_properties_annotation.value)
+                pattern_properties.annotation is not None:
+            evaluated_names |= set(pattern_properties.annotation)
 
         annotation = []
         for name, item in instance.items():
             if name not in evaluated_names:
-                if self.json.evaluate(item, scope).valid:
+                if self.json.evaluate(item, scope).passed:
                     annotation += [name]
 
-        if scope.valid:
-            scope.annotate(instance, self.key, annotation)
+        if scope.passed:
+            scope.annotate(annotation)
 
 
 class UnevaluatedPropertiesKeyword(Keyword, Applicator):
@@ -321,22 +321,22 @@ class UnevaluatedPropertiesKeyword(Keyword, Applicator):
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         evaluated_names = set()
         for properties_annotation in scope.parent.collect_annotations(instance, "properties"):
-            evaluated_names |= set(properties_annotation.value)
+            evaluated_names |= set(properties_annotation)
         for pattern_properties_annotation in scope.parent.collect_annotations(instance, "patternProperties"):
-            evaluated_names |= set(pattern_properties_annotation.value)
+            evaluated_names |= set(pattern_properties_annotation)
         for additional_properties_annotation in scope.parent.collect_annotations(instance, "additionalProperties"):
-            evaluated_names |= set(additional_properties_annotation.value)
+            evaluated_names |= set(additional_properties_annotation)
         for unevaluated_properties_annotation in scope.parent.collect_annotations(instance, "unevaluatedProperties"):
-            evaluated_names |= set(unevaluated_properties_annotation.value)
+            evaluated_names |= set(unevaluated_properties_annotation)
 
         annotation = []
         for name, item in instance.items():
             if name not in evaluated_names:
-                if self.json.evaluate(item, scope).valid:
+                if self.json.evaluate(item, scope).passed:
                     annotation += [name]
 
-        if scope.valid:
-            scope.annotate(instance, self.key, annotation)
+        if scope.passed:
+            scope.annotate(annotation)
 
 
 class PropertyNamesKeyword(Keyword, Applicator):
@@ -346,9 +346,8 @@ class PropertyNamesKeyword(Keyword, Applicator):
     def evaluate(self, instance: JSON, scope: Scope) -> None:
         err_names = []
         for name in instance:
-            if not self.json.evaluate(JSON(name), scope).valid:
+            if not self.json.evaluate(JSON(name, parent=instance, key=name), scope).passed:
                 err_names += [name]
 
         if err_names:
-            scope.errors.clear()
-            scope.fail(instance, f"Property names {err_names} are invalid")
+            scope.fail(f"Property names {err_names} are invalid")
